@@ -3,9 +3,11 @@
 #define _TEOPP_H_
 /* include teo library */  
 /* redefine library version information */
-#define TEOPP_LIB_VERSION "TEO++ ver.2.0"
+#define TEOPP_LIB_VERSION "TEO++ ver.2.4"
 
+extern "C" {
 #include <teo.h>
+}
 
 /* define access mode */
 #ifndef TEO_AC_NOACCESS
